local uabIceHUDFrameGroup = uabFrameGroup:NewModule("IceHUD")

uabIceHUDFrameGroup.controls = {}
uabIceHUDFrameGroup.defaultDB = {
    framegroups = {
        ["TargetInfo"] = {
            expression = "^IceHUD_TargetInfo$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "target",
        },
        ["TargetOfTarget"] = {
            expression = "^IceHUD_TargetOfTarget$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "targettarget",
        },
    },
}

function uabIceHUDFrameGroup:OnInitialize()
    self.super.OnInitialize(self)
end

function uabIceHUDFrameGroup:OnEnable()
end

function uabIceHUDFrameGroup:OnDisable()
end

function uabIceHUDFrameGroup:NewActivator(activator)
	self.controls[activator] = {}
    
    self:AllocateControlsForUnitGroup(activator, "target")
    self:AllocateControlsForUnitGroup(activator, "targettarget")
end

function uabIceHUDFrameGroup:AllocateControlsForUnitGroup(activator, groupname)
    self.controls[activator][groupname] = {}
    
	for idx = 1, uab.constants.groupInfo[groupname].unitcount do
        table.insert(self.controls[activator][groupname], activator:NewUnitGroupControl(groupname))
    end
end

function uabIceHUDFrameGroup:HaveFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)
	
	if not options then return end

	if self.controls[activator] and self.controls[activator][options.unitgroup] then
		return # self.controls[activator][options.unitgroup] > 0
	end
end

function uabIceHUDFrameGroup:NextFrameControl(frame, activator)
	local _, options = self:OptionsForFrame(frame)

	if not options then return end

	local control
	
    if self.controls[activator] and self.controls[activator][options.unitgroup]
        and # self.controls[activator][options.unitgroup] > 0 then
		control = table.remove(self.controls[activator][options.unitgroup])
	end

	return control
end

function uabIceHUDFrameGroup:OptionsForFrame(frame)
    for name, defn in pairs(self.db.profile.framegroups) do
        if self:MatchFrame(frame, defn) then
            return name, defn
        end
    end
end

function uabIceHUDFrameGroup:CreateFrameGroupOptions()
    local args = {}

    args = {
        type = 'group',
        name = "IceHUD",
        desc = "Use, anchor, scale, and match expression for IceHUD frames",
        args = {
            enabled = {
                type = 'toggle',
                name = "Enabled",
                desc = "When checked, enable the use of UAB action sets for IceHUD frames",
                order = 1,
                get = function()
                    return not self.db.profile.disabled
                end,
                set = function(v)
                    self.db.profile.disabled = not v
                    self.core.core.main:FrameGroupsChanged()
                end,
            },
            
            spacing3 = {
                name = " ",
                type = 'header',
                order = 5,
            },
        
        },
    }
    
    args.args["TargetInfo"] = self:CreateFrameGroupOption(self.db.profile.framegroups["TargetInfo"], "TargetInfo", "IceHUD TargetInfo")
    args.args["TargetInfo"].disabled = function() return self.db.profile.disabled end
    args.args["TargetInfo"].order = 10
    
    args.args["TargetOfTarget"] = self:CreateFrameGroupOption(self.db.profile.framegroups["TargetOfTarget"], "TargetOfTarget", "IceHUD TargetOfTarget")
    args.args["TargetOfTarget"].disabled = function() return self.db.profile.disabled end
    args.args["TargetOfTarget"].order = 20
    
    return args
end

function uabIceHUDFrameGroup:SetupLayouts()
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["TargetInfo"].layout, self, "TargetInfo")
    uabLayoutManager:LayoutChanged(self.db.profile.framegroups["TargetOfTarget"].layout, self, "TargetOfTarget")
end

function uabIceHUDFrameGroup:SetLayoutConfigureOptions(name, args)
    self.core.core.options.args.lookandfeel.args.framegroups.args[self.name].args[name].args.layout.args.configure.args = args
end

